@@ -40,21 +40,23 @@
 
 #include <QVBoxLayout>
 
-K_PLUGIN_FACTORY(KOrganizerFactory, registerPlugin<KOrganizerPart>();)
+K_PLUGIN_FACTORY(KOrganizerFactory, registerPlugin<KOrganizerPart>();
+                 )
 
 KOrganizerPart::KOrganizerPart(QWidget *parentWidget, QObject *parent, const QVariantList &)
-    : KParts::ReadOnlyPart(parent),
-      mTopLevelWidget(nullptr)
+    : KParts::ReadOnlyPart(parent)
+    , mTopLevelWidget(nullptr)
 {
     KOrgMigrateApplication migrate;
     migrate.migrate();
     if (parentWidget) {
         mTopLevelWidget = parentWidget->topLevelWidget();
     } else if (parent && parent->isWidgetType()) {
-        mTopLevelWidget = (QWidget *)parent;
+        mTopLevelWidget = dynamic_cast<QWidget *>(parent);
     } else {
         qCCritical(KORGANIZER_LOG) << "Cannot initialize the part without a top level widget.";
     }
+    Q_ASSERT(mTopLevelWidget);
 
     KOCore::self()->addXMLGUIClient(mTopLevelWidget, this);
 
@@ -102,8 +104,9 @@ void KOrganizerPart::slotChangeInfo(const Akonadi::Item &item, const QDate &date
     Q_UNUSED(date);
     const KCalCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
     if (incidence) {
-        Q_EMIT textChanged(incidence->summary() + QLatin1String(" / ") +
-                           KCalUtils::IncidenceFormatter::timeToString(incidence->dtStart().toLocalTime().time()));
+        Q_EMIT textChanged(incidence->summary() + QLatin1String(" / ")
+                           +KCalUtils::IncidenceFormatter::timeToString(incidence->dtStart().
+                                                                        toLocalTime().time()));
     } else {
         Q_EMIT textChanged(QString());
     }
